<?php
/*
Plugin Name: WooCommerce Demo Button / External link (EasyToolsWP)
Description: Add a "See demo" / External link button on WooCommerce single products.
Version: 1.2
Author: EasyToolsWP.com
*/

// Aktiver plugin
function wc_demo_button_activate() {
    // Ingen aktiveringshandling krævet
}
register_activation_hook( __FILE__, 'wc_demo_button_activate' );

// Deaktiver plugin
function wc_demo_button_deactivate() {
    // Ingen deaktiveringshandling krævet
}
register_deactivation_hook( __FILE__, 'wc_demo_button_deactivate' );

// Tilføj metaboks til produktindstillinger
add_action( 'add_meta_boxes', 'wc_demo_button_metabox' );

function wc_demo_button_metabox() {
    add_meta_box(
        'wc_demo_button_metabox',
        'Demo Button Settings',
        'wc_demo_button_metabox_callback',
        'product',
        'normal',
        'high'
    );
}

function wc_demo_button_metabox_callback( $post ) {
    // Hent eksisterende værdier for metafeltet
    $demo_link = get_post_meta( $post->ID, '_demo_link', true );
    $open_new_tab = get_post_meta( $post->ID, '_open_new_tab', true );
    $button_text = get_post_meta( $post->ID, '_button_text', true );

    // Sikre, at variabler er defineret
    $demo_link = isset( $demo_link ) ? esc_attr( $demo_link ) : '';
    $open_new_tab = isset( $open_new_tab ) ? (bool) $open_new_tab : false;
    $button_text = isset( $button_text ) ? esc_attr( $button_text ) : '';

    // Output HTML for metabox
    ?>
    <p>
        <label for="demo_link">Demo Link:</label>
        <input type="text" id="demo_link" name="demo_link" value="<?php echo $demo_link; ?>" style="width: 100%;" />
    </p>
    <p>
        <label for="button_text"><strong>Button Text:</strong></label><br/>
		<span class="etwp-free">Change placeholder in EasyToolsWP settings - <a href="?page=easytoolswp_pro-settings#demobutton">Click here</a><br/>Unlock PRO Features with EasyToolsWP PRO - <a href="https://www.easytoolswp.com/download/pro-features/" target="_blank">Buy now</a></span>
        <span class="etwp-pro"><input type="text" id="button_text" name="button_text" value="<?php echo $button_text; ?>" style="width: 100%;" /></span>
    </p>
    <p>
        <input type="checkbox" id="open_new_tab" name="open_new_tab" <?php checked( $open_new_tab ); ?> />
        <label for="open_new_tab">Open in new tab (target="_blank")</label>
    </p>
    <?php
}

// Gem metaboksdata
add_action( 'save_post', 'wc_demo_button_save_metabox' );

function wc_demo_button_save_metabox( $post_id ) {
    if ( isset( $_POST['demo_link'] ) ) {
        update_post_meta( $post_id, '_demo_link', sanitize_text_field( $_POST['demo_link'] ) );
    }
    if ( isset( $_POST['button_text'] ) ) {
        update_post_meta( $post_id, '_button_text', sanitize_text_field( $_POST['button_text'] ) );
    }
    if ( isset( $_POST['open_new_tab'] ) ) {
        update_post_meta( $post_id, '_open_new_tab', 1 );
    } else {
        update_post_meta( $post_id, '_open_new_tab', 0 );
    }
}

// Vis demo knap under produktbeskrivelsen med tilpasset knaptekst
add_action( 'woocommerce_single_product_summary', 'wc_demo_button_output', 20 );

function wc_demo_button_output() {
    $demo_link = get_post_meta( get_the_ID(), '_demo_link', true );
    $open_new_tab = get_post_meta( get_the_ID(), '_open_new_tab', true ) ? 'target="_blank"' : '';
    $button_text = get_post_meta( get_the_ID(), '_button_text', true );

    if ( empty( $button_text ) ) {
        // Hvis der ikke er angivet en knaptekst, brug standardtekst fra EasyTools subpage
        $button_text = get_option( 'wc_demo_button_default_text', 'See Demo' );
    }

    if ( $demo_link ) {
        echo '<div style="margin-top: 20px;">';
        echo '<a href="' . esc_url( $demo_link ) . '" class="button demo-button" ' . $open_new_tab . '>' . esc_html( $button_text ) . '</a>';
        echo '</div>';
    }
}

// Opret en subpage under EasyTools til at administrere standardtekst for knappen
add_action( 'admin_menu', 'wc_demo_button_easytools_submenu_page' );

function wc_demo_button_easytools_submenu_page() {
    add_submenu_page(
        '', // Parent slug (EasyTools)
        'Demo Button Settings', // Page title
        'Demo Button Settings', // Menu title
        'manage_options', // Capability
        'easytoolswp_pro-settings', // Menu slug
        'wc_demo_button_easytools_settings_page' // Callback function
    );
}

function wc_demo_button_easytools_settings_page() {
    // Sikre kun admin har adgang
    if ( ! current_user_can( 'manage_options' ) ) {
        return;
    }

    // Gem opdaterede standardtekst til knappen
    if ( isset( $_POST['wc_demo_button_default_text'] ) ) {
        update_option( 'wc_demo_button_default_text', sanitize_text_field( $_POST['wc_demo_button_default_text'] ) );
        echo '<div class="updated"><p>Settings saved</p></div>';
    }

    // Hent eksisterende standardtekst
    $default_text = get_option( 'wc_demo_button_default_text', 'See Demo' );

    // Output settings form
    ?>
    <div class="wrap" id="demobutton">
        <form method="post" action="">
		  <h2>WooCommerce Demo/External Button</h2>
            <table class="form-table">
                <tr>
                    <th scope="row"><label for="wc_demo_button_default_text">Default Button Text:</label></th>
                    <td><input type="text" id="wc_demo_button_default_text" name="wc_demo_button_default_text" value="<?php echo esc_attr( $default_text ); ?>" class="regular-text" /></td>
                </tr>
            </table>
            <p class="submit">
                <input type="submit" name="submit" id="submit" class="button button-primary" value="Save Changes">
            </p>
        </form>
    </div>
    <?php
}
